/*
 * Copyright 2000-2013 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.xmlnamespace.panel.vaadin.ui.permissions;

import java.util.Set;

import com.vaadin.ui.AbstractComponent;
import com.xmlnamespace.panel.vaadin.shared.permissions.PermissionEditorServerRpc;
import com.xmlnamespace.panel.vaadin.shared.permissions.PermissionsEditorState;
import com.xmlnamespace.panel.vaadin.shared.permissions.PermissionsEditorState.ClientPermissionGroup;
import com.xmlnamespace.panel.vaadin.shared.permissions.PermissionsEditorState.ClientPermissionType;

/**
 *
 * @since
 * @author Vaadin Ltd
 */
public class PermissionsEditor extends AbstractComponent {
    private static final long serialVersionUID = 8630915887863197666L;

    private PermissionEditorServerRpc rpc = new PermissionEditorServerRpc() {
        private static final long serialVersionUID = -140583996030323918L;

        @Override
        public void policyUpdated(ClientPermissionType type) {
            PermissionsEditor.this.policyUpdated(type);
        }

        /*
         * (non-Javadoc)
         *
         * @see com.xmlnamespace.panel.vaadin.shared.permissions.
         * PermissionEditorServerRpc#setAllTo(java.util.Set, java.lang.String)
         */
        @Override
        public void setAllTo(Set<ClientPermissionType> types, String policy) {
            PermissionsEditor.this.setAllTo(types, policy);
        }
    };

    public PermissionsEditor() {
        registerRpc(rpc);
    }

    protected void policyUpdated(ClientPermissionType type) {
        // Do nothing, subclasses can override
    }

    protected void typeChecked(String identifier, boolean checked) {
        // Do nothing, subclasses can override
    }

    protected void setAllTo(Set<ClientPermissionType> types, final String policy) {
        // Do nothing, subclasses can override
    }

    @Override
    protected PermissionsEditorState getState() {
        return (PermissionsEditorState) super.getState();
    }

    public void setTitleHeaderText(final String header) {
        getState().titleHeader = header;
        markAsDirty();
    }

    public void setTypeHeaderText(final String header) {
        getState().typeHeader = header;
        markAsDirty();
    }

    public void setPolicyHeaderText(final String header) {
        getState().policyHeader = header;
        markAsDirty();
    }

    public void setExceptionsHeaderText(final String header) {
        getState().exceptionsHeader = header;
        markAsDirty();
    }

    public void setPolicyInheritText(final String text) {
        getState().policyInheritText = text;
        markAsDirty();
    }

    public void setPolicyAllowText(final String text) {
        getState().policyAllowText = text;
        markAsDirty();
    }

    public void setPolicyDenyText(final String text) {
        getState().policyDenyText = text;
        markAsDirty();
    }

    public void setPolicyOwnedText(final String text) {
        getState().policyOwnedText = text;
        markAsDirty();
    }

    public void setSelectText(final String selectText) {
        getState().selectText = selectText;
        markAsDirty();
    }

    public void setSelectAllText(final String selectAllText) {
        getState().selectAllText = selectAllText;
        markAsDirty();
    }

    public void setSelectNoneText(final String selectNoneText) {
        getState().selectNoneText = selectNoneText;
        markAsDirty();
    }

    public void setSetSelectedToText(final String setSelectedToText) {
        getState().setSelectedToText = setSelectedToText;
        markAsDirty();
    }

    public void setExceptText(final String exceptText) {
        getState().exceptText = exceptText;
        markAsDirty();
    }

    public void setSuggestionsText(final String suggestionsText) {
        getState().suggestionsText = suggestionsText;
        markAsDirty();
    }

    protected void addGroup(final ClientPermissionGroup group) {
        getState().groups.add(group);
        markAsDirty();
    }

    public void setInheritAllowed(final boolean allowed) {
        getState().allowInherit = allowed;
        markAsDirty();
    }

    public void setSubjectId(final String subjectId) {
        getState().subjectId = subjectId;
        markAsDirty();
    }
}
