/*******************************************************************************
 * I9 TECHNOLOGIES CONFIDENTIAL
 * __________________
 * Copyright © 2013 i9 Technologies 
 * All Rights Reserved.
 * 
 * NOTICE:  All information contained herein is, and remains the property 
 * of i9 Technologies and its suppliers, if any.  The intellectual and technical 
 * concepts contained herein are proprietary to i9 Technologies and its 
 * suppliers and may be covered by U.S. and Foreign Patents, patents in 
 * process, and are protected by trade secret or copyright law. Dissemination 
 * of this information or reproduction of this material is strictly forbidden 
 * unless prior written permission is obtained from i9 Technologies.
 ******************************************************************************/
package org.vaadin.popupbutton;

import org.vaadin.popupbutton.shared.NotificationPopupButtonState;

import com.vaadin.ui.Alignment;

/**
 * An extended version of PopupButton that contains a notification overlay that
 * can be positioned on the popup button.
 */
public class NotificationPopupButton extends PopupButton {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /**
     * Sets the notification count visible.
     * 
     * @param visible
     *            the new notification count visible
     */
    public void setNotificationCountVisible(boolean visible) {
        getState().overlayVisible = visible;
        markAsDirty();
    }

    /**
     * Checks if is notification overlay visible.
     * 
     * @return true, if is notification overlay visible
     */
    public boolean isNotificationOverlayVisible() {
        return getState().overlayVisible;
    }

    /**
     * Sets the notification count.
     * 
     * @param count
     *            the new notification count
     */
    public void setNotificationCount(String count) {
        getState().count = count;
        markAsDirty();
    }

    /**
     * Gets the notification count.
     * 
     * @return the notification count
     */
    public String getNotificationCount() {
        return getState().count;
    }

    /**
     * Sets the x.
     * 
     * @param x
     *            the new x
     */
    public void setX(int x) {
        getState().x = x;
        markAsDirty();
    }

    /**
     * Gets the x.
     * 
     * @return the x
     */
    public int getX() {
        return getState().x;
    }

    /**
     * Sets the y.
     * 
     * @param y
     *            the new y
     */
    public void setY(int y) {
        getState().y = y;
        markAsDirty();
    }

    /**
     * Gets the y.
     * 
     * @return the y
     */
    public int getY() {
        return getState().y;
    }

    /**
     * Sets the align.
     * 
     * @param align
     *            the new align
     */
    public void setAlign(Alignment align) {
        getState().align = align.getBitMask();
        markAsDirty();
    }

    /**
     * Gets the align.
     * 
     * @return the align
     */
    public Alignment getAlign() {
        return new Alignment(getState().align);
    }

    /**
     * Sets the overlay align.
     * 
     * @param overlayAlign
     *            the new overlay align
     */
    public void setOverlayAlign(Alignment overlayAlign) {
        getState().overlayAlign = overlayAlign.getBitMask();
        markAsDirty();
    }

    /**
     * Gets the overlay align.
     * 
     * @return the overlay align
     */
    public Alignment getOverlayAlign() {
        return new Alignment(getState().overlayAlign);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.vaadin.popupbutton.PopupButton#getState()
     */
    @Override
    public NotificationPopupButtonState getState() {
        return (NotificationPopupButtonState) super.getState();
    }

}
